==> AsposeCellsCloud-CellsApi-25.10.tar.gz: AsposeCellsCloud-CellsApi-25.10/docs/model/Validation.md <==
# AsposeCellsCloud::Object::Validation 

## Load the model package
```perl
use AsposeCellsCloud::Object::Validation;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AlertStyle** | **string** | Represents the validation alert style. |
**AreaList** | **ARRAY[CellArea]** | Represents a collection of Aspose.Cells.CellArea which contains the data                validation settings. |
**ErrorMessage** | **string** | Represents the data validation error message. |
**ErrorTitle** | **string** | Represents the title of the data-validation error dialog box. |
**Formula1** | **string** | Represents the value or expression associated with the data validation. |
**Formula2** | **string** | Represents the value or expression associated with the data validation. |
**IgnoreBlank** | **boolean** | Indicates whether blank values are permitted by the range data validation. |
**InCellDropDown** | **boolean** | Indicates whether data validation displays a drop-down list that contains acceptable values. |
**InputMessage** | **string** | Represents the data validation input message. |
**InputTitle** | **string** | Represents the title of the data-validation input dialog box. |
**Operator** | **string** | Represents the operator for the data validation. |
**ShowError** | **boolean** | Indicates whether the data validation error message will be displayed whenever the user enters invalid data. |
**ShowInput** | **boolean** | Indicates whether the data validation input message will be displayed whenever the user selects a cell in the data validation range. |
**Type** | **string** | Represents the data validation type. |
**Value1** | **string** | Represents the first value associated with the data validation. |
**Value2** | **string** | Represents the second value associated with the data validation. |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/Validation.md <==
# AsposeCellsCloud::Object::Validation 

## Load the model package
```perl
use AsposeCellsCloud::Object::Validation;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AlertStyle** | **string** | Represents the validation alert style. |
**AreaList** | **ARRAY[CellArea]** | Represents a collection of Aspose.Cells.CellArea which contains the data                validation settings. |
**ErrorMessage** | **string** | Represents the data validation error message. |
**ErrorTitle** | **string** | Represents the title of the data-validation error dialog box. |
**Formula1** | **string** | Represents the value or expression associated with the data validation. |
**Formula2** | **string** | Represents the value or expression associated with the data validation. |
**IgnoreBlank** | **boolean** | Indicates whether blank values are permitted by the range data validation. |
**InCellDropDown** | **boolean** | Indicates whether data validation displays a drop-down list that contains acceptable values. |
**InputMessage** | **string** | Represents the data validation input message. |
**InputTitle** | **string** | Represents the title of the data-validation input dialog box. |
**Operator** | **string** | Represents the operator for the data validation. |
**ShowError** | **boolean** | Indicates whether the data validation error message will be displayed whenever the user enters invalid data. |
**ShowInput** | **boolean** | Indicates whether the data validation input message will be displayed whenever the user selects a cell in the data validation range. |
**Type** | **string** | Represents the data validation type. |
**Value1** | **string** | Represents the first value associated with the data validation. |
**Value2** | **string** | Represents the second value associated with the data validation. |
**link** | **Link** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
